@@ -12,6 +12,7 @@
 
 /* magic file name for ioctl opens */
 #define SMB_IOCTL_FILENAME	"\\_._AFS_IOCTL_._"	/* double backslashes for C compiler */
+#define SMB_IOCTL_FILENAME_NOSLASH "_._AFS_IOCTL_._"
 
 /* max parms for ioctl, in either direction */
 #define SMB_IOCTL_MAXDATA	8192
@@ -31,7 +32,12 @@ extern long smb_IoctlWrite(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp, sm
 
 extern long smb_IoctlV3Read(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp, smb_packet_t *outp);
 
+#ifndef DJGPP
 extern long smb_IoctlReadRaw(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp,
 	smb_packet_t *outp);
+#else /* DJGPP */
+extern long smb_IoctlReadRaw(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp,
+	smb_packet_t *outp, dos_ptr rawBuf);
+#endif /* !DJGPP */
 
 #endif /*  __SMB_IOCTL_H_ENV__ */
