@@ -18,7 +18,7 @@
 #ifndef _OSI_MACHDEP_H_
 #define _OSI_MACHDEP_H_
 
-#include "../h/kern_sem.h"
+#include "h/kern_sem.h"
 
 #define	afs_hz	    hz
 extern struct timeval time;
@@ -38,6 +38,8 @@ extern struct timeval time;
 
 #undef	afs_suser
 
+#define osi_curcred()		(p_cred(u.u_procp))
+
 #define getpid()                (afs_uint32)p_pid(u.u_procp)
 
 #define getppid()               (afs_uint32)p_ppid(u.u_procp)
@@ -58,24 +60,27 @@ extern b_sema_t afs_global_sema;
 extern void osi_InitGlock(void);
 
 #if !defined(AFS_HPUX110_ENV)
-extern void       afsHash(int nbuckets);
+extern void afsHash(int nbuckets);
 extern sv_sema_t *afsHashInsertFind(tid_t key);
 extern sv_sema_t *afsHashFind(tid_t key);
-extern void       afsHashRelease(tid_t key);
+extern void afsHashRelease(tid_t key);
 
 #define AFS_GLOCK_PID   kt_tid(u.u_kthreadp)
 #define AFS_SAVE_SEMA   afsHashInsertFind(AFS_GLOCK_PID)
 #define AFS_FIND_SEMA   afsHashFind(AFS_GLOCK_PID)
+
 #define AFS_GLOCK()     MP_PXSEMA(&afs_global_sema, AFS_SAVE_SEMA)
 #define AFS_GUNLOCK()   (AFS_ASSERT_GLOCK(), MP_VXSEMA(&afs_global_sema,AFS_FIND_SEMA), (!uniprocessor ? (afsHashRelease(AFS_GLOCK_PID),0) : 0))
 #define ISAFS_GLOCK()   (!uniprocessor ? owns_sema(&afs_global_sema):1)
+
 #else
 #define AFS_GLOCK()  b_psema(&afs_global_sema)
 #define AFS_GUNLOCK() b_vsema(&afs_global_sema)
 #define ISAFS_GLOCK() b_owns_sema(&afs_global_sema)
+
 #endif
 
-#define AFS_RXGLOCK() 
+#define AFS_RXGLOCK()
 #define AFS_RXGUNLOCK()
 #define ISAFS_RXGLOCK() 1
 
@@ -92,11 +97,10 @@ extern void       afsHashRelease(tid_t key);
  */
 
 #define	afs_osi_Sleep(x)	sleep((caddr_t) x,PZERO-2)
-#define	afs_osi_Wakeup(x)	wakeup((caddr_t) x)
 #else
 /*
- * On 11.* global lock is a beta semaphore, hence we need to
- * release and reacquire around sleep and wakeup. We also need to
+ * On 11.22 global lock is a beta semaphore, hence we need to
+ * release and reacquire around sllep and wakeup. We also need to
  * use the get_sleep_lock.
  * afs_osi_Sleep and afs_osi_Wakeup are defined
  */
@@ -104,13 +108,11 @@ void afs_osi_Sleep(void *event);
 int afs_osi_Wakeup(void *event);
 #endif
 
-
 #define	osi_NullHandle(x)	((x)->proc == (caddr_t) 0)
 
 #if !defined(AFS_HPUX110_ENV)
 extern caddr_t kmem_alloc();
 #endif
-
 #include <sys/kthread_iface.h>	/* for kt_cred() */
 
 /* Expected to be available as a patch from HP */
