@@ -12,7 +12,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/butc/tcprocs.c,v 1.5 2001/08/08 00:03:40 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/butc/tcprocs.c,v 1.12.2.2 2005/04/03 18:48:29 shadow Exp $");
 
 #include <sys/types.h>
 #include <errno.h>
@@ -40,35 +41,99 @@ RCSID("$Header: /cvs/openafs/src/butc/tcprocs.c,v 1.5 2001/08/08 00:03:40 shadow
 #include <afs/tcdata.h>
 #include "error_macros.h"
 #include "butc_xbsa.h"
-extern afs_int32 xbsaType;
 
 callPermitted(call)
-    struct rx_call *call;
+     struct rx_call *call;
 {
-    afs_int32                         code;
-
-    struct rx_connection        *tconn;
-    rxkad_level                  level;
-    Date                         expiration;
-    char                         name[MAXKTCNAMELEN];
-    char                         inst[MAXKTCNAMELEN];
-    char                         celn[MAXKTCREALMLEN];
-    afs_int32                         kvno;
-
-    char                        *cell;
-    afs_int32                         flag;
-
     /* before this code can be used, the rx connection, on the bucoord side, must */
     /* be changed so that it will set up for token passing instead of using  a    */
     /* simple rx connection that, below, returns a value of 0 from rx_SecurityClassOf */
     return 1;
 }
 
+/* -----------------------------
+ * misc. routines
+ * -----------------------------
+ */
+
+static int
+CopyDumpDesc(toDump, fromDump)
+     struct tc_dumpDesc *toDump;
+     tc_dumpArray *fromDump;
+{
+    struct tc_dumpDesc *toPtr, *fromPtr;
+    int i;
+
+    toPtr = toDump;
+    fromPtr = fromDump->tc_dumpArray_val;
+    for (i = 0; i < fromDump->tc_dumpArray_len; i++) {
+	toPtr->vid = fromPtr->vid;
+	toPtr->vtype = fromPtr->vtype;
+	toPtr->partition = fromPtr->partition;
+	toPtr->date = fromPtr->date;
+	toPtr->cloneDate = fromPtr->cloneDate;
+	toPtr->hostAddr = fromPtr->hostAddr;
+	strcpy(toPtr->name, fromPtr->name);
+	fromPtr++;
+	toPtr++;
+    }
+    return 0;
+}
+
+
+static int
+CopyRestoreDesc(toRestore, fromRestore)
+     struct tc_restoreDesc *toRestore;
+     tc_restoreArray *fromRestore;
+{
+    struct tc_restoreDesc *toPtr, *fromPtr;
+    int i;
+
+    toPtr = toRestore;
+    fromPtr = fromRestore->tc_restoreArray_val;
+    for (i = 0; i < fromRestore->tc_restoreArray_len; i++) {
+	toPtr->flags = fromPtr->flags;
+	toPtr->position = fromPtr->position;
+	strcpy(toPtr->tapeName, fromPtr->tapeName);
+	toPtr->dbDumpId = fromPtr->dbDumpId;
+	toPtr->initialDumpId = fromPtr->initialDumpId;
+	toPtr->origVid = fromPtr->origVid;
+	toPtr->vid = fromPtr->vid;
+	toPtr->partition = fromPtr->partition;
+	toPtr->dumpLevel = fromPtr->dumpLevel;
+	toPtr->hostAddr = fromPtr->hostAddr;
+	strcpy(toPtr->newName, fromPtr->newName);
+	strcpy(toPtr->oldName, fromPtr->oldName);
+	fromPtr++;
+	toPtr++;
+
+    }
+    return 0;
+}
+
+static int
+CopyTapeSetDesc(toPtr, fromPtr)
+     struct tc_tapeSet *toPtr, *fromPtr;
+{
+
+    toPtr->id = fromPtr->id;
+    toPtr->maxTapes = fromPtr->maxTapes;
+    toPtr->a = fromPtr->a;
+    toPtr->b = fromPtr->b;
+    strcpy(toPtr->tapeServer, fromPtr->tapeServer);
+    strcpy(toPtr->format, fromPtr->format);
+
+    toPtr->expDate = fromPtr->expDate;
+    toPtr->expType = fromPtr->expType;
+    return 0;
+}
+
 /* -------------------------
  * butc - interface routines - alphabetic order
  * -------------------------
  */
 
+afs_int32
 STC_LabelTape(acid, label, taskId)
      struct rx_call *acid;
      struct tc_tapeLabel *label;
@@ -81,91 +146,99 @@ STC_LabelTape(acid, label, taskId)
 #else
     PROCESS pid;
 #endif
-    struct tc_tapeLabel *mylabel;
     struct labelTapeIf *ptr;
     statusP statusPtr;
     afs_int32 code;
 
-     extern int Labeller();
-     extern statusP createStatusNode();
-     extern afs_int32 allocTaskId();
+    extern int Labeller();
+    extern statusP createStatusNode();
+    extern afs_int32 allocTaskId();
 
 #ifdef xbsa
-    if (CONF_XBSA) return(TC_BADTASK);    /* LabelTape does not apply if XBSA */
+    if (CONF_XBSA)
+	return (TC_BADTASK);	/* LabelTape does not apply if XBSA */
 #endif
 
-    if ( callPermitted(acid) == 0 )
-        return(TC_NOTPERMITTED);
+    if (callPermitted(acid) == 0)
+	return (TC_NOTPERMITTED);
 
-    ptr = (struct labelTapeIf *) malloc(sizeof(*ptr));
-    if (!ptr) ERROR_EXIT(TC_NOMEMORY);
+    ptr = (struct labelTapeIf *)malloc(sizeof(*ptr));
+    if (!ptr)
+	ERROR_EXIT(TC_NOMEMORY);
     memcpy(&ptr->label, label, sizeof(ptr->label));
 
     /* set up the status node */
-    *taskId = allocTaskId();			/* for bucoord */
+    *taskId = allocTaskId();	/* for bucoord */
     ptr->taskId = *taskId;
-    
+
     statusPtr = createStatusNode();
-    if ( !statusPtr ) ERROR_EXIT(TC_INTERNALERROR);
+    if (!statusPtr)
+	ERROR_EXIT(TC_INTERNALERROR);
 
     lock_Status();
-    statusPtr->taskId     = *taskId;
+    statusPtr->taskId = *taskId;
     statusPtr->lastPolled = time(0);
-    statusPtr->flags     &= ~STARTING;	       /* ok to examine */
+    statusPtr->flags &= ~STARTING;	/* ok to examine */
     strncpy(statusPtr->taskName, "Labeltape", sizeof(statusPtr->taskName));
     unlock_Status();
 
     /* create the LWP to do the real work behind the scenes */
 #ifdef AFS_PTHREAD_ENV
     code = pthread_attr_init(&tattr);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     code = pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     AFS_SIGSET_CLEAR();
     code = pthread_create(&pid, &tattr, Labeller, ptr);
     AFS_SIGSET_RESTORE();
 #else
-    code = LWP_CreateProcess(Labeller, 32768, 1, ptr ,"labeller process", &pid);
+    code =
+	LWP_CreateProcess(Labeller, 32768, 1, (void *)ptr, "labeller process",
+			  &pid);
 #endif
 
-error_exit:
-    if ( code )
-    {
-        if (statusPtr) deleteStatusNode(statusPtr);
-	if (ptr) free(ptr);
+  error_exit:
+    if (code) {
+	if (statusPtr)
+	    deleteStatusNode(statusPtr);
+	if (ptr)
+	    free(ptr);
     }
 
-    return(code);
+    return (code);
 }
 
 /* STC_PerformDump
  *	Tape coordinator server routine to do a dump
  */
 
+afs_int32
 STC_PerformDump(rxCallId, tcdiPtr, tc_dumpArrayPtr, taskId)
-    struct rx_call *rxCallId;
-    struct tc_dumpInterface *tcdiPtr;
-    tc_dumpArray *tc_dumpArrayPtr;
-    afs_int32 *taskId;
+     struct rx_call *rxCallId;
+     struct tc_dumpInterface *tcdiPtr;
+     tc_dumpArray *tc_dumpArrayPtr;
+     afs_int32 *taskId;
 {
     struct dumpNode *newNode = 0;
-    statusP	    statusPtr = 0;
+    statusP statusPtr = 0;
 #ifdef AFS_PTHREAD_ENV
-    pthread_t       pid;
-    pthread_attr_t  tattr;
+    pthread_t pid;
+    pthread_attr_t tattr;
     AFS_SIGSET_DECL;
 #else
-    PROCESS         pid;
+    PROCESS pid;
 #endif
-    afs_int32           code = 0;
+    afs_int32 code = 0;
 
     extern statusP createStatusNode();
     extern Dumper();
 
-    if ( callPermitted(rxCallId) == 0 )
-        return(TC_NOTPERMITTED);
+    if (callPermitted(rxCallId) == 0)
+	return (TC_NOTPERMITTED);
 
     /* should be verifying parameter validity */
     *taskId = 0;
@@ -176,16 +249,18 @@ STC_PerformDump(rxCallId, tcdiPtr, tc_dumpArrayPtr, taskId)
     /*set up the parameters in the node, to be used by LWP */
     strcpy(newNode->dumpSetName, tcdiPtr->dumpName);
 
-    newNode->dumpName = (char *) malloc(strlen(tcdiPtr->dumpPath)+1);
+    newNode->dumpName = (char *)malloc(strlen(tcdiPtr->dumpPath) + 1);
     strcpy(newNode->dumpName, tcdiPtr->dumpPath);
 
-    newNode->volumeSetName = (char *) malloc(strlen(tcdiPtr->volumeSetName)+1);
+    newNode->volumeSetName =
+	(char *)malloc(strlen(tcdiPtr->volumeSetName) + 1);
     strcpy(newNode->volumeSetName, tcdiPtr->volumeSetName);
 
     CopyTapeSetDesc(&(newNode->tapeSetDesc), &tcdiPtr->tapeSet);
 
     newNode->dumps = (struct tc_dumpDesc *)
-	malloc(sizeof(struct tc_dumpDesc) * tc_dumpArrayPtr->tc_dumpArray_len);
+	malloc(sizeof(struct tc_dumpDesc) *
+	       tc_dumpArrayPtr->tc_dumpArray_len);
     newNode->arraySize = tc_dumpArrayPtr->tc_dumpArray_len;
     CopyDumpDesc(newNode->dumps, tc_dumpArrayPtr);
 
@@ -193,17 +268,19 @@ STC_PerformDump(rxCallId, tcdiPtr, tc_dumpArrayPtr, taskId)
     newNode->level = tcdiPtr->dumpLevel;
     newNode->doAppend = tcdiPtr->doAppend;
 #ifdef xbsa
-    if (CONF_XBSA) newNode->doAppend = 0;    /* Append flag is ignored if talking to XBSA */
+    if (CONF_XBSA)
+	newNode->doAppend = 0;	/* Append flag is ignored if talking to XBSA */
 #endif
 
     /* create the status node */
     statusPtr = createStatusNode();
-    if ( !statusPtr ) ERROR_EXIT(TC_INTERNALERROR);
+    if (!statusPtr)
+	ERROR_EXIT(TC_INTERNALERROR);
 
     lock_Status();
-    statusPtr->taskId     = newNode->taskID;
+    statusPtr->taskId = newNode->taskID;
     statusPtr->lastPolled = time(0);
-    statusPtr->flags     &= ~STARTING;                     /* ok to examine */
+    statusPtr->flags &= ~STARTING;	/* ok to examine */
     strncpy(statusPtr->taskName, "Dump", sizeof(statusPtr->taskName));
     unlock_Status();
 
@@ -212,34 +289,40 @@ STC_PerformDump(rxCallId, tcdiPtr, tc_dumpArrayPtr, taskId)
     /* create the LWP to do the real work behind the scenes */
 #ifdef AFS_PTHREAD_ENV
     code = pthread_attr_init(&tattr);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     code = pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     AFS_SIGSET_CLEAR();
     code = pthread_create(&pid, &tattr, Dumper, newNode);
     AFS_SIGSET_RESTORE();
 #else
-    code = LWP_CreateProcess(Dumper, 32768, 1, newNode, "dumper process", &pid);
+    code =
+	LWP_CreateProcess(Dumper, 32768, 1, (void *)newNode, "dumper process",
+			  &pid);
 #endif
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     *taskId = newNode->taskID;
 
-error_exit:
-    if (code)
-    {
-        if (statusPtr) deleteStatusNode(statusPtr);
-        FreeNode(newNode->taskID);      /*  failed to create LWP to do the dump. */
+  error_exit:
+    if (code) {
+	if (statusPtr)
+	    deleteStatusNode(statusPtr);
+	FreeNode(newNode->taskID);	/*  failed to create LWP to do the dump. */
     }
 
-    return(code);
+    return (code);
 }
 
+afs_int32
 STC_PerformRestore(acid, dumpSetName, arestores, taskID)
      struct rx_call *acid;
-     char *dumpSetName;               /* not used */
+     char *dumpSetName;		/* not used */
      tc_restoreArray *arestores;
      afs_int32 *taskID;
 {
@@ -257,8 +340,8 @@ STC_PerformRestore(acid, dumpSetName, arestores, taskID)
     extern int Restorer();
     extern statusP createStatusNode();
 
-    if ( callPermitted(acid) == 0 )
-        return(TC_NOTPERMITTED);
+    if (callPermitted(acid) == 0)
+	return (TC_NOTPERMITTED);
 
     /* should  verify parameter validity */
 
@@ -266,20 +349,22 @@ STC_PerformRestore(acid, dumpSetName, arestores, taskID)
     CreateNode(&newNode);
 
     newNode->restores = (struct tc_restoreDesc *)
-        malloc (sizeof(struct tc_restoreDesc) * arestores->tc_restoreArray_len);
+	malloc(sizeof(struct tc_restoreDesc) *
+	       arestores->tc_restoreArray_len);
     newNode->arraySize = arestores->tc_restoreArray_len;
-    CopyRestoreDesc(newNode->restores,arestores);
+    CopyRestoreDesc(newNode->restores, arestores);
     *taskID = newNode->taskID;
 
     /* should log the intent */
 
     /* create the status node */
     statusPtr = createStatusNode();
-    if ( !statusPtr ) ERROR_EXIT(TC_INTERNALERROR);
+    if (!statusPtr)
+	ERROR_EXIT(TC_INTERNALERROR);
 
     lock_Status();
-    statusPtr->taskId     = newNode->taskID;
-    statusPtr->flags     &= ~STARTING;                     /* ok to examine */
+    statusPtr->taskId = newNode->taskID;
+    statusPtr->flags &= ~STARTING;	/* ok to examine */
     statusPtr->lastPolled = time(0);
     strncpy(statusPtr->taskName, "Restore", sizeof(statusPtr->taskName));
     unlock_Status();
@@ -289,28 +374,33 @@ STC_PerformRestore(acid, dumpSetName, arestores, taskID)
     /* create the LWP to do the real work behind the scenes */
 #ifdef AFS_PTHREAD_ENV
     code = pthread_attr_init(&tattr);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     code = pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     AFS_SIGSET_CLEAR();
     code = pthread_create(&pid, &tattr, Restorer, newNode);
     AFS_SIGSET_RESTORE();
 #else
-    code = LWP_CreateProcess(Restorer, 65368, 1,newNode ,"restorer process", &pid);
+    code =
+	LWP_CreateProcess(Restorer, 65368, 1, (void *)newNode,
+			  "restorer process", &pid);
 #endif
 
-error_exit:
-    if ( code )
-    {
-        if (statusPtr) deleteStatusNode(statusPtr);
-        FreeNode(newNode->taskID);                 /*  failed to create LWP to do the dump. */
+  error_exit:
+    if (code) {
+	if (statusPtr)
+	    deleteStatusNode(statusPtr);
+	FreeNode(newNode->taskID);	/*  failed to create LWP to do the dump. */
     }
 
-    return(code);
+    return (code);
 }
 
+afs_int32
 STC_ReadLabel(acid, label, taskId)
      struct rx_call *acid;
      struct tc_tapeLabel *label;
@@ -319,15 +409,16 @@ STC_ReadLabel(acid, label, taskId)
     afs_int32 code;
 
     extern int ReadLabel();
-   
+
 #ifdef xbsa
-    if (CONF_XBSA) return(TC_BADTASK);    /* ReadLabel does not apply if XBSA */
+    if (CONF_XBSA)
+	return (TC_BADTASK);	/* ReadLabel does not apply if XBSA */
 #endif
 
-    if ( callPermitted(acid) == 0 )
-        return(TC_NOTPERMITTED);
+    if (callPermitted(acid) == 0)
+	return (TC_NOTPERMITTED);
 
-    code = ReadLabel(label); /* Synchronous */
+    code = ReadLabel(label);	/* Synchronous */
     return code;
 }
 
@@ -335,6 +426,7 @@ STC_ReadLabel(acid, label, taskId)
  *	restore the backup database from tape
  */
 
+afs_int32
 STC_RestoreDb(rxCall, taskId)
      struct rx_call *rxCall;
      afs_uint32 *taskId;
@@ -354,55 +446,62 @@ STC_RestoreDb(rxCall, taskId)
     extern afs_int32 allocTaskId();
 
 #ifdef xbsa
-    if (CONF_XBSA) return(TC_BADTASK);    /* LabelTape does not apply if XBSA */
+    if (CONF_XBSA)
+	return (TC_BADTASK);	/* LabelTape does not apply if XBSA */
 #endif
 
-    if ( callPermitted(rxCall) == 0 )
-        return(TC_NOTPERMITTED);
+    if (callPermitted(rxCall) == 0)
+	return (TC_NOTPERMITTED);
 
     *taskId = allocTaskId();
 
     /* create the status node */
     statusPtr = createStatusNode();
-    if ( !statusPtr ) ERROR_EXIT(TC_INTERNALERROR);
+    if (!statusPtr)
+	ERROR_EXIT(TC_INTERNALERROR);
 
     lock_Status();
-    statusPtr->taskId     = *taskId;
-    statusPtr->flags     &= ~STARTING;                     /* ok to examine */
+    statusPtr->taskId = *taskId;
+    statusPtr->flags &= ~STARTING;	/* ok to examine */
     statusPtr->lastPolled = time(0);
     strncpy(statusPtr->taskName, "RestoreDb", sizeof(statusPtr->taskName));
     unlock_Status();
 
 #ifdef AFS_PTHREAD_ENV
     code = pthread_attr_init(&tattr);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     code = pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     AFS_SIGSET_CLEAR();
     code = pthread_create(&pid, &tattr, restoreDbFromTape, (void *)*taskId);
     AFS_SIGSET_RESTORE();
 #else
-    code = LWP_CreateProcess(restoreDbFromTape, 32768, 1, *taskId, "Db restore", &pid);
+    code =
+	LWP_CreateProcess(restoreDbFromTape, 32768, 1, (void *)*taskId,
+			  "Db restore", &pid);
 #endif
 
-error_exit:
-    if ( code )
-    {
-        if (statusPtr) deleteStatusNode(statusPtr);
+  error_exit:
+    if (code) {
+	if (statusPtr)
+	    deleteStatusNode(statusPtr);
     }
 
-    return(code);
+    return (code);
 }
 
 /* STC_SaveDb
  *	restore the backup database from tape
  */
 
+afs_int32
 STC_SaveDb(rxCall, archiveTime, taskId)
      struct rx_call *rxCall;
-     Date   archiveTime;
+     Date archiveTime;
      afs_uint32 *taskId;
 {
 #ifdef AFS_PTHREAD_ENV
@@ -421,27 +520,30 @@ STC_SaveDb(rxCall, archiveTime, taskId)
     extern afs_int32 allocTaskId();
 
 #ifdef xbsa
-    if (CONF_XBSA) return(TC_BADTASK);    /* LabelTape does not apply if XBSA */
+    if (CONF_XBSA)
+	return (TC_BADTASK);	/* LabelTape does not apply if XBSA */
 #endif
 
-    if ( callPermitted(rxCall) == 0 )
-        return(TC_NOTPERMITTED);
+    if (callPermitted(rxCall) == 0)
+	return (TC_NOTPERMITTED);
 
     *taskId = allocTaskId();
 
-    ptr = (struct saveDbIf *) malloc(sizeof(struct saveDbIf));
-    if (!ptr) ERROR_EXIT(TC_NOMEMORY);
+    ptr = (struct saveDbIf *)malloc(sizeof(struct saveDbIf));
+    if (!ptr)
+	ERROR_EXIT(TC_NOMEMORY);
     ptr->archiveTime = archiveTime;
-    ptr->taskId      = *taskId;
+    ptr->taskId = *taskId;
 
     /* create the status node */
     statusPtr = createStatusNode();
-    if ( !statusPtr ) ERROR_EXIT(TC_INTERNALERROR);
+    if (!statusPtr)
+	ERROR_EXIT(TC_INTERNALERROR);
 
     lock_Status();
-    statusPtr->taskId     = *taskId;
+    statusPtr->taskId = *taskId;
     statusPtr->lastPolled = time(0);
-    statusPtr->flags     &= ~STARTING;                     /* ok to examine */
+    statusPtr->flags &= ~STARTING;	/* ok to examine */
     strncpy(statusPtr->taskName, "SaveDb", sizeof(statusPtr->taskName));
     unlock_Status();
 
@@ -449,28 +551,31 @@ STC_SaveDb(rxCall, archiveTime, taskId)
 
 #ifdef AFS_PTHREAD_ENV
     code = pthread_attr_init(&tattr);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     code = pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     AFS_SIGSET_CLEAR();
     code = pthread_create(&pid, &tattr, saveDbToTape, ptr);
     AFS_SIGSET_RESTORE();
 #else
-    code = LWP_CreateProcess(saveDbToTape, 32768, 1, ptr ,"Db save", &pid);
+    code = LWP_CreateProcess(saveDbToTape, 32768, 1, ptr, "Db save", &pid);
 #endif
 
-error_exit:
-    if ( code )
-    {
-        if (statusPtr) deleteStatusNode(statusPtr);
-        if (ptr) free(ptr);
+  error_exit:
+    if (code) {
+	if (statusPtr)
+	    deleteStatusNode(statusPtr);
+	if (ptr)
+	    free(ptr);
     }
 
-    return(code);
+    return (code);
 }
-	
+
 
 /* STC_ScanDumps
  * 	read a dump (maybe more than one tape), and print out a summary
@@ -479,6 +584,7 @@ error_exit:
  *	addDbFlag - if set, the information will be added to the database
  */
 
+afs_int32
 STC_ScanDumps(acid, addDbFlag, taskId)
      struct rx_call *acid;
      afs_int32 addDbFlag;
@@ -500,49 +606,56 @@ STC_ScanDumps(acid, addDbFlag, taskId)
     extern statusP createStatusNode();
 
 #ifdef xbsa
-    if (CONF_XBSA) return(TC_BADTASK);    /* ScanDumps does not apply if XBSA */
+    if (CONF_XBSA)
+	return (TC_BADTASK);	/* ScanDumps does not apply if XBSA */
 #endif
 
-    if ( callPermitted(acid) == 0 )
-        return(TC_NOTPERMITTED);
+    if (callPermitted(acid) == 0)
+	return (TC_NOTPERMITTED);
 
     *taskId = allocTaskId();
 
-    ptr = (struct scanTapeIf *) malloc(sizeof(*ptr));
-    if (!ptr) ERROR_EXIT(TC_NOMEMORY);
+    ptr = (struct scanTapeIf *)malloc(sizeof(*ptr));
+    if (!ptr)
+	ERROR_EXIT(TC_NOMEMORY);
     ptr->addDbFlag = addDbFlag;
     ptr->taskId = *taskId;
 
     /* create the status node */
     statusPtr = createStatusNode();
-    if ( !statusPtr ) ERROR_EXIT(TC_INTERNALERROR);
+    if (!statusPtr)
+	ERROR_EXIT(TC_INTERNALERROR);
 
     lock_Status();
-    statusPtr->taskId     = *taskId;
+    statusPtr->taskId = *taskId;
     statusPtr->lastPolled = time(0);
-    statusPtr->flags     &= ~STARTING;                     /* ok to examine */
+    statusPtr->flags &= ~STARTING;	/* ok to examine */
     strncpy(statusPtr->taskName, "Scantape", sizeof(statusPtr->taskName));
     unlock_Status();
 
 #ifdef AFS_PTHREAD_ENV
     code = pthread_attr_init(&tattr);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     code = pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
-    if (code) ERROR_EXIT(code);
+    if (code)
+	ERROR_EXIT(code);
 
     AFS_SIGSET_CLEAR();
     code = pthread_create(&pid, &tattr, ScanDumps, ptr);
     AFS_SIGSET_RESTORE();
 #else
-    code = LWP_CreateProcess(ScanDumps,32768, 1, ptr, "scandump process",&pid);
+    code =
+	LWP_CreateProcess(ScanDumps, 32768, 1, ptr, "scandump process", &pid);
 #endif
 
-error_exit:
-    if ( code )
-    {
-        if (statusPtr) deleteStatusNode(statusPtr);
-	if (ptr) free(ptr);
+  error_exit:
+    if (code) {
+	if (statusPtr)
+	    deleteStatusNode(statusPtr);
+	if (ptr)
+	    free(ptr);
     }
 
     return code;
@@ -553,158 +666,97 @@ error_exit:
  *	is just the version number of the interface
  */
 
+afs_int32
 STC_TCInfo(acid, tciptr)
      struct rx_call *acid;
      struct tc_tcInfo *tciptr;
 {
-    if ( callPermitted(acid) == 0 )
-        return(TC_NOTPERMITTED);
+    if (callPermitted(acid) == 0)
+	return (TC_NOTPERMITTED);
 
     tciptr->tcVersion = CUR_BUTC_VERSION;
-    return(0);
+    return (0);
 }
 
 /* STC_DeleteDump
  */
+afs_int32
 STC_DeleteDump(acid, dumpID, taskId)
-   struct rx_call *acid;
-   afs_int32 *taskId;
+     struct rx_call *acid;
+     afs_uint32 dumpID;
+     afs_uint32 *taskId;
 {
-   struct deleteDumpIf *ptr=0;
-   statusP statusPtr=0;
-   afs_int32 code = TC_BADTASK;   /* If not compiled -Dxbsa then fail */
+    struct deleteDumpIf *ptr = 0;
+    statusP statusPtr = 0;
+    afs_int32 code = TC_BADTASK;	/* If not compiled -Dxbsa then fail */
+#ifdef xbsa
 #ifdef AFS_PTHREAD_ENV
     pthread_t pid;
     pthread_attr_t tattr;
     AFS_SIGSET_DECL;
 #else
     PROCESS pid;
+#endif
 #endif
     extern afs_int32 DeleteDump();
     extern statusP createStatusNode();
     extern afs_int32 allocTaskId();
 
-   *taskId = 0;
-   if (!CONF_XBSA) return(TC_BADTASK);   /* Only do if butc is started as XBSA */
+    *taskId = 0;
+    if (!CONF_XBSA)
+	return (TC_BADTASK);	/* Only do if butc is started as XBSA */
 
 #ifdef xbsa
-   code = 0;
-   if ( callPermitted(acid) == 0 )
-      return(TC_NOTPERMITTED);
+    code = 0;
+    if (callPermitted(acid) == 0)
+	return (TC_NOTPERMITTED);
 
-   ptr = (struct deleteDumpIf *) malloc(sizeof(*ptr));
-   if (!ptr) ERROR_EXIT(TC_NOMEMORY);
+    ptr = (struct deleteDumpIf *)malloc(sizeof(*ptr));
+    if (!ptr)
+	ERROR_EXIT(TC_NOMEMORY);
 
-   *taskId = allocTaskId();
-   ptr->dumpID = dumpID;
-   ptr->taskId = *taskId;
+    *taskId = allocTaskId();
+    ptr->dumpID = dumpID;
+    ptr->taskId = *taskId;
 
-   statusPtr = createStatusNode();
-   if (!statusPtr) ERROR_EXIT(TC_INTERNALERROR);
+    statusPtr = createStatusNode();
+    if (!statusPtr)
+	ERROR_EXIT(TC_INTERNALERROR);
 
-   lock_Status();
-   statusPtr->taskId     = *taskId;
-   statusPtr->lastPolled = time(0);
-   statusPtr->flags     &= ~STARTING;
-   strncpy(statusPtr->taskName, "DeleteDump", sizeof(statusPtr->taskName));
-   unlock_Status();
+    lock_Status();
+    statusPtr->taskId = *taskId;
+    statusPtr->lastPolled = time(0);
+    statusPtr->flags &= ~STARTING;
+    strncpy(statusPtr->taskName, "DeleteDump", sizeof(statusPtr->taskName));
+    unlock_Status();
 
 #ifdef AFS_PTHREAD_ENV
-   code = pthread_attr_init(&tattr);
-   if (code) ERROR_EXIT(code);
+    code = pthread_attr_init(&tattr);
+    if (code)
+	ERROR_EXIT(code);
 
-   code = pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
-   if (code) ERROR_EXIT(code);
+    code = pthread_attr_setdetachstate(&tattr, PTHREAD_CREATE_DETACHED);
+    if (code)
+	ERROR_EXIT(code);
 
-   AFS_SIGSET_CLEAR();
-   code = pthread_create(&pid, &tattr, DeleteDump, ptr);
-   AFS_SIGSET_RESTORE();
+    AFS_SIGSET_CLEAR();
+    code = pthread_create(&pid, &tattr, DeleteDump, ptr);
+    AFS_SIGSET_RESTORE();
 #else
-   code = LWP_CreateProcess(DeleteDump, 32768, 1, ptr, "deletedump process", &pid);
+    code =
+	LWP_CreateProcess(DeleteDump, 32768, 1, ptr, "deletedump process",
+			  &pid);
 #endif
 
-error_exit:
-   if (code) {
-      if (statusPtr) deleteStatusNode(statusPtr);
-      if (ptr) free(ptr);
-   }
+  error_exit:
+    if (code) {
+	if (statusPtr)
+	    deleteStatusNode(statusPtr);
+	if (ptr)
+	    free(ptr);
+    }
 #endif /* xbsa */
 
-   return(code);
+    return (code);
 }
 
-/* -----------------------------
- * misc. routines
- * -----------------------------
- */
-
-static
-CopyDumpDesc(toDump, fromDump)
-     struct tc_dumpDesc *toDump;
-     tc_dumpArray *fromDump;
-{
-    struct tc_dumpDesc *toPtr, *fromPtr;
-    int i;
-
-    toPtr   = toDump;
-    fromPtr = fromDump->tc_dumpArray_val;
-    for(i = 0 ; i < fromDump->tc_dumpArray_len; i++)
-    {
-	toPtr->vid       = fromPtr->vid;
-	toPtr->vtype     = fromPtr->vtype;
-	toPtr->partition = fromPtr->partition;
-	toPtr->date      = fromPtr->date;
-	toPtr->cloneDate = fromPtr->cloneDate;
-	toPtr->hostAddr  = fromPtr->hostAddr;
-	strcpy(toPtr->name,fromPtr->name);
-	fromPtr++;
-	toPtr++;
-    }
-    return 0;
-}
-
-
-static CopyRestoreDesc(toRestore, fromRestore)
-struct tc_restoreDesc *toRestore;
-tc_restoreArray *fromRestore;
-{
-    struct tc_restoreDesc *toPtr, *fromPtr;
-    int i;
-    
-    toPtr = toRestore ;
-    fromPtr = fromRestore->tc_restoreArray_val;
-    for(i = 0 ; i < fromRestore->tc_restoreArray_len ; i++){
-	toPtr->flags         = fromPtr->flags;
-	toPtr->position      = fromPtr->position;
-	strcpy(toPtr->tapeName,fromPtr->tapeName);
-	toPtr->dbDumpId      = fromPtr->dbDumpId;
-	toPtr->initialDumpId = fromPtr->initialDumpId;
-	toPtr->origVid       = fromPtr->origVid;
-	toPtr->vid           = fromPtr->vid;
-	toPtr->partition     = fromPtr->partition;
-	toPtr->dumpLevel     = fromPtr->dumpLevel;
-	toPtr->hostAddr      = fromPtr->hostAddr;
-	strcpy(toPtr->newName,fromPtr->newName);
-	strcpy(toPtr->oldName, fromPtr->oldName);
-	fromPtr++;
-	toPtr++;
-
-    }
-    return 0;
-}
-
-static CopyTapeSetDesc(toPtr,fromPtr)
-struct tc_tapeSet *toPtr,*fromPtr;
-{
-    
-    toPtr->id = fromPtr->id;
-    toPtr->maxTapes = fromPtr->maxTapes;
-    toPtr->a = fromPtr->a;
-    toPtr->b = fromPtr->b;
-    strcpy(toPtr->tapeServer,fromPtr->tapeServer);
-    strcpy(toPtr->format,fromPtr->format);
-
-    toPtr->expDate = fromPtr->expDate;
-    toPtr->expType = fromPtr->expType;
-    return 0;
-}
